EnvelopeGenerator

Struct EnvelopeGenerator 

pub struct EnvelopeGenerator {
    pub state: State,
    pub envelope_counter: u8,
    pub exponential_counter: u8,
    pub exponential_counter_period: u8,
    pub hold_zero: bool,
    pub rate_counter: u16,
    pub rate_counter_period: u16,
    /* private fields */
}
A 15 bit counter is used to implement the envelope rates, in effect dividing the clock to the envelope counter by the currently selected rate period. In addition, another counter is used to implement the exponential envelope decay, in effect further dividing the clock to the envelope counter. The period of this counter is set to 1, 2, 4, 8, 16, 30 at the envelope counter values 255, 93, 54, 26, 14, 6, respectively.

Fields

state: Stateenvelope_counter: u8exponential_counter: u8exponential_counter_period: u8hold_zero: boolrate_counter: u16rate_counter_period: u16

Implementations

Source

impl EnvelopeGenerator

pub fn get_attack_decay(&self) -> u8

pub fn get_control(&self) -> u8

pub fn get_sustain_release(&self) -> u8

pub fn set_attack_decay(&mut self, value: u8)

pub fn set_control(&mut self, value: u8)

pub fn set_sustain_release(&mut self, value: u8)

pub fn clock(&mut self)

pub fn clock_delta(&mut self, delta: u32)

pub fn output(&self) -> u8

pub fn read_env(&self) -> u8

pub fn reset(&mut self)