ExternalFilter

Struct ExternalFilter 

pub struct ExternalFilter { /* private fields */ }
The audio output stage in a Commodore 64 consists of two STC networks, a low-pass filter with 3-dB frequency 16kHz followed by a high-pass filter with 3-dB frequency 16Hz (the latter provided an audio equipment input impedance of 1kOhm). The STC networks are connected with a BJT supposedly meant to act as a unity gain buffer, which is not really how it works. A more elaborate model would include the BJT, however DC circuit analysis yields BJT base-emitter and emitter-base impedances sufficiently low to produce additional low-pass and high-pass 3dB-frequencies in the order of hundreds of kHz. This calls for a sampling frequency of several MHz, which is far too high for practical use.

Implementations

Source

impl ExternalFilter

pub fn new(chip_model: ChipModel) -> Self

pub fn set_enabled(&mut self, enabled: bool)

pub fn clock(&mut self, vi: i32)

pub fn clock_delta(&mut self, delta: u32, vi: i32)

pub fn output(&self) -> i32

pub fn reset(&mut self)