Filter

Struct Filter 

pub struct Filter {
    pub vhp: i32,
    pub vbp: i32,
    pub vlp: i32,
    pub vnf: i32,
    /* private fields */
}
The SID filter is modeled with a two-integrator-loop biquadratic filter, which has been confirmed by Bob Yannes to be the actual circuit used in the SID chip.

Measurements show that excellent emulation of the SID filter is achieved, except when high resonance is combined with high sustain levels. In this case the SID op-amps are performing less than ideally and are causing some peculiar behavior of the SID filter. This however seems to have more effect on the overall amplitude than on the color of the sound.

The theory for the filter circuit can be found in “Microelectric Circuits” by Adel S. Sedra and Kenneth C. Smith. The circuit is modeled based on the explanation found there except that an additional inverter is used in the feedback from the bandpass output, allowing the summer op-amp to operate in single-ended mode. This yields inverted filter outputs with levels independent of Q, which corresponds with the results obtained from a real SID.

We have been able to model the summer and the two integrators of the circuit to form components of an IIR filter. Vhp is the output of the summer, Vbp is the output of the first integrator, and Vlp is the output of the second integrator in the filter circuit.

According to Bob Yannes, the active stages of the SID filter are not really op-amps. Rather, simple NMOS inverters are used. By biasing an inverter into its region of quasi-linear operation using a feedback resistor from input to output, a MOS inverter can be made to act like an op-amp for small signals centered around the switching threshold.

Fields

vhp: i32vbp: i32vlp: i32vnf: i32

Implementations

Source

impl Filter

pub fn new(chip_model: ChipModel) -> Self

pub fn get_fc_hi(&self) -> u8

pub fn get_fc_lo(&self) -> u8

pub fn get_mode_vol(&self) -> u8

pub fn get_res_filt(&self) -> u8

pub fn set_enabled(&mut self, enabled: bool)

pub fn set_fc_hi(&mut self, value: u8)

pub fn set_fc_lo(&mut self, value: u8)

pub fn set_mode_vol(&mut self, value: u8)

pub fn set_res_filt(&mut self, value: u8)

pub fn clock(&mut self, voice1: i32, voice2: i32, voice3: i32, ext_in: i32)

pub fn clock_delta( &mut self, delta: u32, voice1: i32, voice2: i32, voice3: i32, ext_in: i32, )

pub fn output(&self) -> i32

pub fn reset(&mut self)