Syncable

Struct Syncable 

pub struct Syncable<T> {
    pub main: T,
    pub sync_source: T,
    pub sync_dest: T,
}

Fields

main: Tsync_source: Tsync_dest: T

Implementations

Source

impl Syncable<&Voice>

pub fn output(&self) -> i32

Source

impl<'a> Syncable<&'a Voice>

Source

impl<'a> Syncable<&'a mut Voice>

pub fn wave(self) -> Syncable<&'a mut WaveformGenerator>

Source

impl Syncable<&WaveformGenerator>

pub fn read_osc(&self) -> u8

Source

impl Syncable<&mut WaveformGenerator>

pub fn synchronize(&mut self)

Synchronize oscillators. This must be done after all the oscillators have been clock()’ed since the oscillators operate in parallel. Note that the oscillators must be clocked exactly on the cycle when the MSB is set high for hard sync to operate correctly. See SID::clock().