pub struct Syncable<T> {
pub main: T,
pub sync_source: T,
pub sync_dest: T,
}Fields
main: Tsync_source: Tsync_dest: TImplementations
Sourceimpl<'a> Syncable<&'a mut Voice>
impl<'a> Syncable<&'a mut Voice>
pub fn wave(self) -> Syncable<&'a mut WaveformGenerator>
Sourceimpl Syncable<&mut WaveformGenerator>
impl Syncable<&mut WaveformGenerator>
Sourcepub fn synchronize(&mut self)
pub fn synchronize(&mut self)
Synchronize oscillators. This must be done after all the oscillators have been clock()’ed since the oscillators operate in parallel. Note that the oscillators must be clocked exactly on the cycle when the MSB is set high for hard sync to operate correctly. See SID::clock().